;; Get the descriptions for the keys under FixedProfile
(defun get-inventory-description-fixedprofile (subkey subkeyValue / )
  (cond
    ((= subkey "General")
       (progn
         (cond
           ((= subkeyValue "FavoriteMaterialLibrary")
             "\nMaterial Favorites Library:\nContains the materials added to your Favorites library.\nACTION: Copy the file to tyour new release."
	   )
           ((= subkeyValue "ProfileStorage")
             "\nFixed Profile:\nContains the order of Tool Palettes along with the placements of palettes.\nACTION: Save your workspace with WSSAVE and use the CUSTOMIZE command to export and import tool palette groups."
	   )
	   ((= subkeyValue subkeyValue)
             "\nNo description is available for this item."
	   )
	 )
       )
    )
  )
)

;; Need to include the utilities to Expand Variables

;; Get the menus loaded via the ActiveX COM library via Menugroups
(prompt "\n\nMenu files currently loaded: ")
(setq fileNames "\n")
(vlax-for mnuGroup (vla-get-MenuGroups (vlax-get-acad-object))
  (setq fileNames (strcat fileNames "  " (vla-get-Name mnuGroup) "  " (vla-get-MenuFileName mnuGroup) "\n"))
)
(prompt fileNames)


;; Get the installation location of AutoCAD so we can exclude files from this location
(setq sAcadLocation (vl-registry-read (strcat "HKEY_LOCAL_MACHINE\\" (vlax-machine-product-key)) "AcadLocation"))

;; Get the FixedProfile key
(setq sFixedProfileKey (strcat "HKEY_CURRENT_USER\\" (vlax-user-product-key) "\\FixedProfile"))

;; Get a list of all configured profiles, so we can walk their paths
(setq sProfilesKey (strcat "HKEY_CURRENT_USER\\" (vlax-user-product-key) "\\Profiles"))
(setq lstProfiles (vl-registry-descendents sProfilesKey))

;; Define list of subkeys to walk for each Profile
(setq subKeysProfile (list 
                           (list "Editor Configuration" (list "CustomDictionary" "FontMappingFile" "LogFilePath"))
                           (list "General" (list "ACAD" "ACTRECPATH" "AuthorPalettePath" "AVEMAPS" "ColorBookLocation" "DatabaseWorkSpacePath" "DGNMAPPINGPATH" "TemplatePath"))
                           (list "General Configuration" (list "EnterpriseMenuFile" "IconFilePath" "MenuFile"))
                     )
)



(foreach profileName lstProfiles
  (prompt (strcat "\n" profileName))
  (foreach subKeyProfile subKeysProfile
    (prompt (strcat "\n  " (car subKeyProfile)))
    
    (foreach subKeyValue (cadr subKeyProfile)
      (prompt (strcat "\n    " subKeyValue))
      (prompt (strcat "\n      " (vl-registry-read (strcat sProfilesKey "\\" profileName "\\" (car subKeyProfile)) subKeyValue)))
    )
  )
)

;; Walk the plug-in bundles that were loaded in the last session
(prompt "\n\nPlug-in bundle(s) previously successfully loaded: - NO MIGRATION REQUIRED")
(setq sLoadedKey (strcat "HKEY_CURRENT_USER\\" (vlax-user-product-key) "\\Loaded"))
(setq lstLoaded (vl-registry-descendents sLoadedKey))
(if (= (type lstLoaded) 'LIST)
  (if (> (length lstLoaded) 0)
    (foreach loadedKeyValue lstLoaded
      (setq val (vl-registry-read (strcat sLoadedKey "\\" loadedKeyValue) "ProductCode"))
      (if (/= val nil)
        (prompt (strcat "\n  " loadedKeyValue))
      )
    )
    (prompt "\No plug-in bundles were used.")
  )
  (prompt "\No plug-in bundles were used.")
)

;; Define list of subkeys to walk for the FixedProfile
(setq subKeysFixed (list 
                         (list "General" (list "FavoriteMaterialLibrary" "ProfileStorage"))
                   )
)

;; Walk the FixedProfile key
(prompt "\n\nItems under Fixed Profile: - SUGGESTED MIGRATION")
(foreach subKey subKeysFixed
  (foreach subKeyValue (cadr subKey)
    (setq val (vl-registry-read (strcat sFixedProfileKey "\\" (car subKey)) subKeyValue))
    (if (findfile val)
      (progn
        (prompt (get-inventory-description-fixedprofile (car subKey) subKeyValue))	
        (prompt (strcat "\n  " val))
      )
    )
  )
  (prompt "\n")
)